@@ -67,9 +67,10 @@ module Control.Concurrent.Async.Lifted.Safe
   , Unsafe.link, Unsafe.link2
 
     -- * Convenient utilities
-  , race, race_, concurrently
+  , race, race_, concurrently, concurrently_
   , mapConcurrently, mapConcurrently_
   , forConcurrently, forConcurrently_
+  , replicateConcurrently, replicateConcurrently_
   , Concurrently(..)
 
 
@@ -87,6 +88,7 @@ module Control.Concurrent.Async.Lifted.Safe
 import Control.Applicative
 import Control.Concurrent (threadDelay)
 import Control.Monad
+import Data.Foldable (fold)
 
 import Control.Concurrent.Async (Async)
 import Control.Exception.Lifted (SomeException, Exception)
@@ -327,6 +329,12 @@ concurrently
   => m a -> m b -> m (a, b)
 concurrently = liftBaseOp2_ A.concurrently
 
+-- | Generalized version of 'A.concurrently_'.
+concurrently_
+  :: forall m a b. (MonadBaseControl IO m, Forall (Pure m))
+  => m a -> m b -> m ()
+concurrently_ = liftBaseOp2_ A.concurrently_
+
 -- | Similar to 'A.liftBaseOp_' but takes a binary function
 -- and leverages @'StM' m a ~ a@.
 liftBaseOp2_
@@ -369,6 +377,24 @@ forConcurrently_
   -> m ()
 forConcurrently_ = flip mapConcurrently_
 
+-- | Generalized version of 'A.replicateConcurrently'.
+replicateConcurrently
+  :: (MonadBaseControl IO m, Forall (Pure m))
+  => Int
+  -> m a
+  -> m [a]
+replicateConcurrently n =
+  runConcurrently . sequenceA . replicate n . Concurrently
+
+-- | Generalized version of 'A.replicateConcurrently_'.
+replicateConcurrently_
+  :: (MonadBaseControl IO m, Forall (Pure m))
+  => Int
+  -> m a
+  -> m ()
+replicateConcurrently_ n =
+  runConcurrently . fold . replicate n . Concurrently . void
+
 -- | Generalized version of 'A.Concurrently'.
 --
 -- A value of type @'Concurrently' m a@ is an IO-based operation that can be
